use strict;

sub mkprint
{
    my $line = shift;
    print MAKE $line."\n";
}
sub mkprinttab
{
    my $line = shift;
    print MAKE "\t".$line."\n";
}
sub askval
{
    my $value = shift;
    my $title = shift;
    my $val;
    print "$title [$$value]: ";
    $val = <STDIN>;
    chomp($val);
    if ($val)
    {
	$$value = $val;
    }
}

my $dbvers = `mynews dbversion`;
chomp($dbvers);
if (!$dbvers)
{
    print "\n";
    print "*** Error: MyNews website requires MyNews script to be installed ***\n";
    print "$dbvers\n";
    print "\n";
    exit;
}

my $conf_path = '/etc';

askval(\$conf_path, "Conf dir");

my $puburl = '';
my $pubdir = '';

open(CONF, "$conf_path/mynews.conf") || die "Unable to open MyNews conf file $conf_path/mynews.conf";
my $line;
my $webdir = "";
my $weburl = "";
my $dbtype = "";
my $dbname = "";
my $dbuser = "";
my $key;
my $val;
while ($line = <CONF>)
{
    if ($line =~ /^\s*(\S+)\s*=\s*(.*)$/)
    {
	$key = $1;
	$val = $2;
	if ($key eq 'type')
	{
	    $dbtype = $val;
	}
	elsif ($key eq 'database')
	{
	    $dbname = $val;
	}
	elsif ($key eq 'user')
	{
	    $dbuser = $val;
	}
	elsif ($key eq 'webdir')
	{
	    $webdir = $val;
	}
	elsif ($key eq 'weburl')
	{
	    $weburl = $val;
	}
	elsif ($key eq 'pubdir')
	{
	    $pubdir = $val;
	}
	elsif ($key eq 'puburl')
	{
	    $puburl = $val;
	}
    }
}
close(CONF);

my $haspub;
if ($puburl)
{
    $haspub = 1;
}
if (!$puburl)
{
    $haspub = 0;
    askval(\$puburl, "Public website URL (optional)");
    if ($puburl)
    {
	$pubdir = '/var/www/mynewspub';
	askval(\$pubdir, "Public website directory");
    }
}

my @st = stat("$conf_path/mynews.conf");
my $mnuser = getpwuid($st[4]);
my $mngroup = getgrgid($st[5]);
if (!defined $mnuser)
{
    $mnuser = $st[4];
}
if (!defined $mngroup)
{
    $mngroup = $st[5];
}

my $lsl = `ls lang/*/name`;
my @langs = $lsl =~ /lang\/([^\/]+)\//mg;
my $lang;

print "Writing Makefile for mynews www\n";
open(MAKE, ">Makefile");

mkprint('# Makefile to install mynews www');
mkprint();
mkprint('DB_TYPE = '.$dbtype);
mkprint('DB_NAME = '.$dbname);
mkprint('DB_USER = '.$dbuser);
mkprint('WEB_DIR = '.$webdir);
mkprint('WEB_URL = '.$weburl);
if ($pubdir)
{
    mkprint('PUB_DIR = '.$pubdir);
    mkprint('PUB_URL = '.$puburl);
}
mkprint('MN_USER = '.$mnuser);
mkprint('MN_GROUP = '.$mngroup);
mkprint();
mkprint('BUILD_DIR = build');
mkprint('HTACCESS = htaccess');
mkprint('ADMIN_HTACCESS = adminhtaccess');
mkprint('MAKEFILE = Makefile');
mkprint('MAKEFILE_OLD = Makefile.old');
mkprint('MNWWW = t/mnwww.t');
mkprint('MYDOC = mydoc');
mkprint();
mkprint('PERL = '.$^X);
mkprint('SHELL = /bin/sh');
mkprint('NOOP = $(SHELL) -c true');
mkprint('NOECHO = @');
mkprint('ECHO = echo');
mkprint('ECHON = echo -n');
mkprint('CHMOD = chmod');
mkprint('CHOWN = chown');
mkprint('CHGRP = chgrp');
mkprint('CP = cp');
mkprint('MV = mv');
mkprint('MKDIR = mkdir -p');
mkprint('LN_SF = ln -sf');
mkprint('RM_F = rm -f');
mkprint('RM_RF = rm -rf');
mkprint('PRINT_HT = echo >> $(BUILD_DIR)/$(HTACCESS)');
mkprint('PRINT_AHT = echo >> $(BUILD_DIR)/$(ADMIN_HTACCESS)');
mkprint('PRINT_CONF = echo >> '.$conf_path.'/mynews.conf');
mkprint();
mkprint('.SUFFIXES: .html .xml');
mkprint('.xml.html :');
mkprinttab('$(MYDOC) $<');
mkprint();
mkprint('all : $(BUILD_DIR) $(BUILD_DIR)/$(HTACCESS) $(BUILD_DIR)/$(ADMIN_HTACCESS) doc');
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyNews built successfully');
mkprinttab('$(NOECHO) $(ECHO)');
mkprint();
mkprint('cleandoc :');
mkprinttab('$(RM_F) lang/*/*.html');
mkprint();
mkprint('clean : cleandoc');
mkprinttab('$(RM_RF) $(BUILD_DIR)');
mkprinttab('$(RM_F) lang/*/*.html');
mkprinttab('$(MV) $(MAKEFILE) $(MAKEFILE_OLD)');
mkprint();
mkprint('realclean : clean');
mkprinttab('$(RM_F) $(MAKEFILE_OLD)');
mkprint();
mkprint('$(BUILD_DIR) :');
mkprinttab('$(MKDIR) $(BUILD_DIR)');
mkprint();
mkprint('$(BUILD_DIR)/$(HTACCESS) :');
mkprinttab('$(PRINT_HT) \'AuthName "MyNews"\'');
mkprinttab('$(PRINT_HT) "AuthType Basic"');
if ($dbtype eq 'pgsql')
{
    mkprinttab('$(PRINT_HT) "Auth_PG_host localhost"');
    mkprinttab('$(PRINT_HT) "Auth_PG_port 5432"');
    mkprinttab('$(PRINT_HT) "Auth_PG_user $(DB_USER)"');
    mkprinttab('$(PRINT_HT) "Auth_PG_database $(DB_NAME)"');
    mkprinttab('$(PRINT_HT) "Auth_PG_pwd_table mnuser"');
    mkprinttab('$(PRINT_HT) "Auth_PG_grp_table mnusergroup"');
    mkprinttab('$(PRINT_HT) "Auth_PG_uid_field login"');
    mkprinttab('$(PRINT_HT) "Auth_PG_gid_field groupid"');
    mkprinttab('$(PRINT_HT) "Auth_PG_pwd_field password"');
}
elsif ($dbtype eq 'mysql')
{
    mkprinttab('$(PRINT_HT) "AuthGroupFile /dev/null"');
    mkprinttab('$(PRINT_HT) "AuthMySQLHost localhost"');
    mkprinttab('$(PRINT_HT) "AuthMySQLUser $(DB_USER)"');
    mkprinttab('$(PRINT_HT) "AuthMySQLDB $(DB_NAME)"');
    mkprinttab('$(PRINT_HT) "AuthMySQLUserTable mnuser"');
    mkprinttab('$(PRINT_HT) "AuthMySQLGroupTable mnusergroup"');
    mkprinttab('$(PRINT_HT) "AuthMySQLNameField login"');
    mkprinttab('$(PRINT_HT) "AuthMySQLGroupField groupid"');
    mkprinttab('$(PRINT_HT) "AuthMySQLPasswordField password"');
}
mkprinttab('$(PRINT_HT) "<LIMIT GET POST>"');
mkprinttab('$(PRINT_HT) "Require valid-user"');
mkprinttab('$(PRINT_HT) "</LIMIT>"');
mkprint();
mkprint('$(BUILD_DIR)/$(ADMIN_HTACCESS) :');
mkprinttab('$(PRINT_AHT) \'AuthName "MyNews"\'');
mkprinttab('$(PRINT_AHT) "AuthType Basic"');
if ($dbtype eq 'pgsql')
{
    mkprinttab('$(PRINT_AHT) "Auth_PG_host localhost"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_port 5432"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_user $(DB_USER)"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_database $(DB_NAME)"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_pwd_table mnuser"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_grp_table mnusergroup"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_uid_field login"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_gid_field groupid"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_pwd_field password"');
}
elsif ($dbtype eq 'mysql')
{
    mkprinttab('$(PRINT_AHT) "AuthGroupFile /dev/null"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLHost localhost"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLUser $(DB_USER)"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLDB $(DB_NAME)"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLUserTable mnuser"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLGroupTable mnusergroup"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLNameField login"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLGroupField groupid"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLPasswordField password"');
}
mkprinttab('$(PRINT_AHT) "<LIMIT GET POST>"');
mkprinttab('$(PRINT_AHT) "Require group admin"');
mkprinttab('$(PRINT_AHT) "</LIMIT>"');

mkprint();
mkprint('doc :'.join("", map {" doc_$_"} @langs));
mkprinttab('$(NOECHO) $(NOOP)');
mkprint();
mkprint('install_doc :'.join("", map {" install_doc_$_"} @langs));
mkprinttab('$(NOECHO) $(NOOP)');
mkprint();
my $instline = 'install : all $(WEB_DIR) $(WEB_DIR)/cache install_scripts install_admin install_css install_img install_lang install_doc';
if ($pubdir)
{
    $instline .= " installpub";
}
mkprint($instline);
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyNews website installed successfully');
mkprinttab('$(NOECHO) $(ECHO)');
mkprint();
mkprint('$(WEB_DIR) :');
mkprinttab('$(MKDIR) $(WEB_DIR)');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)');
mkprint();
mkprint('$(WEB_DIR)/cache :');
mkprinttab('$(MKDIR) $(WEB_DIR)/cache');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/cache');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/cache');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/cache');
mkprint();
mkprint('$(WEB_DIR)/admin :');
mkprinttab('$(MKDIR) $(WEB_DIR)/admin');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/admin');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/admin');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/admin');
mkprint();
mkprint('$(WEB_DIR)/css :');
mkprinttab('$(MKDIR) $(WEB_DIR)/css');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/css');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/css');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/css');
mkprint();
mkprint('$(WEB_DIR)/css/themes : $(WEB_DIR)/css');
mkprinttab('$(MKDIR) $(WEB_DIR)/css/themes');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/css/themes');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/css/themes');
mkprinttab('$(CHMOD) 0770  $(WEB_DIR)/css/themes');
mkprint();
mkprint('$(WEB_DIR)/img :');
mkprinttab('$(MKDIR) $(WEB_DIR)/img');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/img');
mkprint();
mkprint('$(WEB_DIR)/img/flags : $(WEB_DIR)/img');
mkprinttab('$(MKDIR) $(WEB_DIR)/img/flags');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/flags');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/flags');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/img/flags');
mkprint();
mkprint('$(WEB_DIR)/img/templates : $(WEB_DIR)/img');
mkprinttab('$(MKDIR) $(WEB_DIR)/img/templates');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/templates');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/templates');
mkprinttab('$(CHMOD) 0770  $(WEB_DIR)/img/templates');
mkprint();
mkprint('$(WEB_DIR)/img/topics : $(WEB_DIR)/img');
mkprinttab('$(MKDIR) $(WEB_DIR)/img/topics');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/topics');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/topics');
mkprinttab('$(CHMOD) 0770  $(WEB_DIR)/img/topics');
mkprint();
mkprint('$(WEB_DIR)/lang :');
mkprinttab('$(MKDIR) $(WEB_DIR)/lang');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/lang');
mkprint();
mkprint('$(WEB_DIR)/.htaccess :');
mkprinttab('$(CP) $(BUILD_DIR)/$(HTACCESS) $(WEB_DIR)/.htaccess');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/.htaccess');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/.htaccess');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/.htaccess');
mkprint();
mkprint('install_scripts : $(BUILD_DIR)/$(HTACCESS) $(WEB_DIR)/.htaccess');
mkprinttab('$(CP) *.cgi $(WEB_DIR)');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/*.cgi');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/*.cgi');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/*.cgi');
mkprinttab('$(CP) version.txt $(WEB_DIR)');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/version.txt');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/version.txt');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/version.txt');
mkprint();
mkprint('$(WEB_DIR)/admin/.htaccess :');
mkprinttab('$(CP) $(BUILD_DIR)/$(ADMIN_HTACCESS) $(WEB_DIR)/admin/.htaccess');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/admin/.htaccess');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/admin/.htaccess');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/admin/.htaccess');
mkprint();
mkprint('install_admin : $(WEB_DIR)/admin $(BUILD_DIR)/$(ADMIN_HTACCESS) $(WEB_DIR)/admin/.htaccess');
mkprinttab('$(CP) admin/*.cgi $(WEB_DIR)/admin');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/admin/*.cgi');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/admin/*.cgi');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/admin/*.cgi');
mkprint();
mkprint('install_css : $(WEB_DIR)/css $(WEB_DIR)/css/themes');
mkprinttab('$(CP) css/*.css $(WEB_DIR)/css');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/css/*.css');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/css/*.css');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/css/*.css');
mkprint();
mkprint('install_img : $(WEB_DIR)/img $(WEB_DIR)/img/flags $(WEB_DIR)/img/topics $(WEB_DIR)/img/templates');
mkprinttab('$(CP) img/*.png $(WEB_DIR)/img');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/*.png');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/*.png');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/img/*.png');
mkprinttab('$(CP) img/flags/*.png $(WEB_DIR)/img/flags');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/flags/*.png');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/flags/*.png');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/img/flags/*.png');
mkprint();
mkprint('install_lang : $(WEB_DIR)/lang'.join("", map {" install_lang_$_"} @langs));
mkprinttab('$(NOECHO) $(NOOP)');
mkprint();
foreach $lang (@langs)
{
    mkprint('$(WEB_DIR)/lang/'.$lang.' :');
    mkprinttab('$(MKDIR) $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/lang/'.$lang);
    mkprint();
    mkprint('doc_'.$lang.' : $(patsubst %.xml,%.html,$(wildcard lang/'.$lang.'/*.xml))');
    mkprinttab('$(NOECHO) $(NOOP)');
    mkprint();
    mkprint('install_lang_'.$lang.' : $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CP) lang/'.$lang.'/messages $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/messages');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/messages');
    mkprinttab('$(CHMOD) 0640  $(WEB_DIR)/lang/'.$lang.'/messages');
    mkprinttab('$(CP) lang/'.$lang.'/name $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/name');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/name');
    mkprinttab('$(CHMOD) 0640  $(WEB_DIR)/lang/'.$lang.'/name');
    mkprint();
    mkprint('install_doc_'.$lang.' : install_lang_'.$lang);
    mkprinttab('$(CP) lang/'.$lang.'/*.html $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/*.html');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/*.html');
    mkprinttab('$(CHMOD) 0640  $(WEB_DIR)/lang/'.$lang.'/*.html');
    mkprinttab('$(CP) lang/'.$lang.'/index.cgi $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/index.cgi');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/index.cgi');
    mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/lang/'.$lang.'/index.cgi');
    mkprint();
}

if ($pubdir)
{
    mkprint('installpub_doc :'.join("", map {" installpub_doc_$_"} @langs));
    mkprinttab('$(NOECHO) $(NOOP)');
    mkprint();
    mkprint('installpub : all $(PUB_DIR) installpub_scripts installpub_css installpub_img installpub_lang installpub_doc');
    if ($haspub)
    {
	mkprinttab('$(NOECHO) $(NOOP)');
    }
    else
    {
	mkprinttab('$(PRINT_CONF) "puburl = $(PUB_URL)"');
	mkprinttab('$(PRINT_CONF) "pubdir = $(PUB_DIR)"');
    }
    mkprint();
    mkprint('$(PUB_DIR) :');
    mkprinttab('$(MKDIR) $(PUB_DIR)');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)');
    mkprint();
    mkprint('$(PUB_DIR)/admin :');
    mkprinttab('$(MKDIR) $(PUB_DIR)/admin');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/admin');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/admin');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/admin');
    mkprint();
    mkprint('$(PUB_DIR)/css :');
    mkprinttab('$(MKDIR) $(PUB_DIR)/css');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/css');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/css');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/css');
    mkprint();
    mkprint('$(PUB_DIR)/css/themes : $(PUB_DIR)/css');
    mkprinttab('$(LN_SF) $(WEB_DIR)/css/themes $(PUB_DIR)/css/themes');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/css/themes');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/css/themes');
    mkprinttab('$(CHMOD) 0770  $(PUB_DIR)/css/themes');
    mkprint();
    mkprint('$(PUB_DIR)/img :');
    mkprinttab('$(MKDIR) $(PUB_DIR)/img');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/img');
    mkprint();
    mkprint('$(PUB_DIR)/img/flags : $(PUB_DIR)/img');
    mkprinttab('$(MKDIR) $(PUB_DIR)/img/flags');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/flags');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/flags');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/img/flags');
    mkprint();
    mkprint('$(PUB_DIR)/img/templates : $(PUB_DIR)/img');
    mkprinttab('$(LN_SF) $(WEB_DIR)/img/templates $(PUB_DIR)/img/templates');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/templates');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/templates');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/img/templates');
    mkprint();
    mkprint('$(PUB_DIR)/img/topics : $(PUB_DIR)/img');
    mkprinttab('$(LN_SF) $(WEB_DIR)/img/topics $(PUB_DIR)/img/topics');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/topics');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/topics');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/img/topics');
    mkprint();
    mkprint('$(PUB_DIR)/lang :');
    mkprinttab('$(MKDIR) $(PUB_DIR)/lang');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/lang');
    mkprint();
    mkprint('installpub_scripts : $(BUILD_DIR)/$(HTACCESS)');
    mkprinttab('$(CP) *.cgi $(PUB_DIR)');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/*.cgi');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/*.cgi');
    mkprinttab('$(CHMOD) 0750 $(PUB_DIR)/*.cgi');
    mkprinttab('$(CP) version.txt $(PUB_DIR)');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/version.txt');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/version.txt');
    mkprinttab('$(CHMOD) 0640 $(PUB_DIR)/version.txt');
    mkprint();
    mkprint('installpub_css : $(PUB_DIR)/css $(PUB_DIR)/css/themes');
    mkprinttab('$(CP) css/*.css $(PUB_DIR)/css');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/css/*.css');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/css/*.css');
    mkprinttab('$(CHMOD) 0750 $(PUB_DIR)/css/*.css');
    mkprint();
    mkprint('installpub_img : $(PUB_DIR)/img $(PUB_DIR)/img/flags $(PUB_DIR)/img/topics $(PUB_DIR)/img/templates');
    mkprinttab('$(CP) img/*.png $(PUB_DIR)/img');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/*.png');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/*.png');
    mkprinttab('$(CHMOD) 0640 $(PUB_DIR)/img/*.png');
    mkprinttab('$(CP) img/flags/*.png $(PUB_DIR)/img/flags');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/flags/*.png');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/flags/*.png');
    mkprinttab('$(CHMOD) 0640 $(PUB_DIR)/img/flags/*.png');
    mkprint();
    mkprint('installpub_lang : $(PUB_DIR)/lang'.join("", map {" installpub_lang_$_"} @langs));
    mkprinttab('$(NOECHO) $(NOOP)');
    mkprint();
    foreach $lang (@langs)
    {
	mkprint('$(PUB_DIR)/lang/'.$lang.' :');
	mkprinttab('$(MKDIR) $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/lang/'.$lang);
	mkprint();
	mkprint('installpub_lang_'.$lang.' : $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CP) lang/'.$lang.'/messages $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/messages');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/messages');
	mkprinttab('$(CHMOD) 0640  $(PUB_DIR)/lang/'.$lang.'/messages');
	mkprinttab('$(CP) lang/'.$lang.'/name $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/name');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/name');
	mkprinttab('$(CHMOD) 0640  $(PUB_DIR)/lang/'.$lang.'/name');
	mkprint();
	mkprint('installpub_doc_'.$lang.' : installpub_lang_'.$lang);
	mkprinttab('$(CP) lang/'.$lang.'/*.html $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/*.html');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/*.html');
	mkprinttab('$(CHMOD) 0640  $(PUB_DIR)/lang/'.$lang.'/*.html');
	mkprinttab('$(CP) lang/'.$lang.'/index.cgi $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/index.cgi');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/index.cgi');
	mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/lang/'.$lang.'/index.cgi');
	mkprint();
    }
}

mkprint('uninstall :');
mkprinttab('$(RM_RF) $(WEB_DIR)');
if ($pubdir)
{
    mkprinttab('$(RM_RF) $(PUB_DIR)');
}
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyNews website uninstalled successfully');
mkprinttab('$(NOECHO) $(ECHO)');
mkprint();
mkprint('test :');
mkprinttab('$(PERL) $(MNWWW)');
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyNews website tested successfully');
mkprinttab('$(NOECHO) $(ECHO)');

close(MAKE);
