#!/usr/bin/perl

use strict;
use MN 1.0;

my $mne = new MN::Engine();

my $cgi = new MN::CGI();

if ($mne->{conf}->{pubregistration} ne "yes")
{
    $cgi->error("Registration disabled");
}

my $code = "";

if ($cgi->{create})
{
    if (!$cgi->{login} || $cgi->{login} =~ /\W/)
    {
	$cgi->setAlert("You must enter a valid login (alphanumeric characters only)");
    }
    elsif ($cgi->{mail} && $cgi->{mail} !~ /^\S+\@\S+$/)
    {
	$cgi->setAlert("Invalid E-mail address");
    }
    else
    {
	my $user = MN::User->getObject($cgi->{login});
	if ($user)
	{
	    $cgi->setAlert("User %s already exists", $cgi->{login});
	}
	elsif (!$cgi->{password1} || !$cgi->{password2} || $cgi->{password1} ne $cgi->{password2})
	{
	    $cgi->setAlert("Password mismatch");
	}
	else
	{
	    $user = new MN::User();
	    $user->{login} = $cgi->{login};
	    $user->{firstname} = $cgi->{firstname};
	    $user->{lastname} = $cgi->{lastname};
	    $user->{mail} = $cgi->{mail};
	    $user->setPassword($cgi->{password1});
	    $user->{lang} = $cgi->prefLang();
	    if ($mne->{conf}->{pubtheme})
	    {
		$user->{theme} = $mne->{conf}->{pubtheme};
	    }
	    $user->setAllDisplay();
	    $user->{newsperpage}= $mne->getNPP();
	    $user->add();
	    
	    $code .= "<div class=\"welcome\">\n";
	    $code .=  __("Your account has been created");
	    $code .= "<p>\n";
	    $code .=  sprintf(__("Click on %s to access to your private area"), '<a href="'.$mne->{conf}->{privurl}.'">'.__("Login")."</a>");
	    $code .= "</div >\n";
	}
    }
}

print $cgi->headerCode(__("Register"), "/register.cgi");

print $cgi->menuCode();

if ($code)
{
    print $code;
}
else
{
    print "<form method=\"post\">\n";
    
    print "<table border=0 cellspacing=0 cellpadding=0 class=\"form\">\n";
    
    print "<caption class=\"formtitle\">\n";
    print __("Create account")."\n";
    print "</caption>\n";
    
    print '<tr class="formtr">'."\n";
    print '<td class="formtopleft"></td>'."\n";
    print '<td colspan=2 class="formtop"></td>'."\n";
    print '<td class="formtopright"></td>'."\n";
    print "</tr>\n";
    
    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td colspan=2 class="formtd" align="center">'."\n";
    print __("Required fields")."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";

    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td class="formlabel">'."\n";
    print __("Login")."\n";
    print "</td>\n";
    print '<td class="formtd">'."\n";
    print '<input class="forminput" type="text" name="login" value="'.$cgi->unquote($cgi->{login}).'" size="20">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";
    
    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td class="formlabel">'."\n";
    print __("Password")."\n";
    print "</td>\n";
    print '<td class="formtd">'."\n";
    print '<input class="forminput" type="password" name="password1" size="20">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";
    
    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td class="formlabel">'."\n";
    print __("One more time")."\n";
    print "</td>\n";
    print '<td class="formtd">'."\n";
    print '<input class="forminput" type="password" name="password2" size="20">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";

    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td colspan=2 class="formtd" align="center">'."\n";
    print '<hr class="formseparator">'."\n";
    print __("Optional fields")."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";

    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td class="formlabel">'."\n";
    print __("First name")."\n";
    print "</td>\n";
    print '<td class="formtd">'."\n";
    print '<input class="forminput" type="text" name="firstname" value="'.$cgi->unquote($cgi->{firstname}).'" size="30">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";
    
    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td class="formlabel">'."\n";
    print __("Last name")."\n";
    print "</td>\n";
    print '<td class="formtd">'."\n";
    print '<input class="forminput" type="text" name="lastname" value="'.$cgi->unquote($cgi->{lastname}).'" size="30">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";
    
    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td class="formlabel">'."\n";
    print __("E-mail address")."\n";
    print "</td>\n";
    print '<td class="formtd">'."\n";
    print '<input class="forminput" type="text" name="mail" value="'.$cgi->unquote($cgi->{mail}).'" size="30">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";
        
    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td colspan=2 class="formtd">'."\n";
    print '<hr class="formseparator">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";

    print '<tr class="formtr">'."\n";
    print '<td class="formleft"></td>'."\n";
    print '<td colspan=2 class="formtd">'."\n";
    print '<input class="formbutton" type="submit" name="create" value="'.__("Create").'">'."\n";
    print '<input class="formbutton2" type="submit" onclick="top.location.href=\''.$ENV{SCRIPT_NAME}.'\';return false;" value="'.__("Cancel").'">'."\n";
    print "</td>\n";
    print '<td class="formright"></td>'."\n";
    print "</tr>\n";
    
    print '<tr class="formtr">'."\n";
    print '<td class="formbottomleft"></td>'."\n";
    print '<td colspan=2 class="formbottom"></td>'."\n";
    print '<td class="formbottomright"></td>'."\n";
    print "</tr>\n";

    print "</table>\n";
    
    print "</form>\n";
}

print $cgi->footerCode();
